import * as i0 from '@angular/core';
import { inject, ViewContainerRef, TemplateRef, Directive, Input, Renderer2, ElementRef, SecurityContext, Component, ViewChild, HostListener } from '@angular/core';
import { getUVEState } from '@dotcms/uve';
import { UVE_MODE } from '@dotcms/uve/types';
import { IMAGE_LOADER } from '@angular/common';
import { TINYMCE_SCRIPT_SRC, EditorComponent } from '@tinymce/tinymce-angular';
import { DomSanitizer } from '@angular/platform-browser';
import { NOTIFY_CLIENT, isInsideEditor, DotCmsClient, postMessageToEditor, CLIENT_ACTIONS } from '@dotcms/client';

/**
 * Directive to show a template when the UVE is in a specific mode.
 *
 * @example
 * <div *dotCMSShowWhen="UVE_MODE.EDIT">
 *     This will be shown when the UVE is in edit mode.
 * </div>
 *
 * @export
 * @class DotCMSShowWhenDirective
 */
class DotCMSShowWhenDirective {
    #when = UVE_MODE.EDIT;
    #hasView = false;
    set dotCMSShowWhen(value) {
        this.#when = value;
        this.updateViewContainer();
    }
    #viewContainerRef = inject(ViewContainerRef);
    #templateRef = inject(TemplateRef);
    updateViewContainer() {
        const state = getUVEState();
        const shouldShow = state?.mode === this.#when;
        if (shouldShow && !this.#hasView) {
            this.#viewContainerRef.createEmbeddedView(this.#templateRef);
            this.#hasView = true;
        }
        else if (!shouldShow && this.#hasView) {
            this.#viewContainerRef.clear();
            this.#hasView = false;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.3", ngImport: i0, type: DotCMSShowWhenDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "18.2.3", type: DotCMSShowWhenDirective, isStandalone: true, selector: "[dotCMSShowWhen]", inputs: { dotCMSShowWhen: "dotCMSShowWhen" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.3", ngImport: i0, type: DotCMSShowWhenDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[dotCMSShowWhen]',
                    standalone: true
                }]
        }], propDecorators: { dotCMSShowWhen: [{
                type: Input
            }] } });

/**
 * Validates if a given path is a valid URL string
 *
 * @param path - The path to validate
 * @returns boolean indicating if the path is valid
 */
function isValidPath(path) {
    if (typeof path !== 'string' || path.trim() === '') {
        return false;
    }
    try {
        new URL(path);
        return true;
    }
    catch {
        return false;
    }
}
/**
 * Provides a DotCMS image loader configuration for the Angular Image directive
 *
 * @param path - The base URL path to the DotCMS instance, or empty to use current site
 * @returns An array of providers for the IMAGE_LOADER token
 * @throws Error if the provided path is invalid
 * @example
 * ```typescript
 * // In your app.config.ts
 * export const appConfig: ApplicationConfig = {
 *   providers: [
 *     provideDotCMSImageLoader('https://demo.dotcms.com')
 *     // Or use current site:
 *     // provideDotCMSImageLoader()
 *   ]
 * };
 * ```
 */
function provideDotCMSImageLoader(path) {
    // If path is provided, validate it
    if (path && !isValidPath(path)) {
        throw new Error(`Image loader has detected an invalid path (\`${path}\`). ` +
            `To fix this, supply either the full URL to the dotCMS site, or leave it empty to use the current site.`);
    }
    return [
        {
            provide: IMAGE_LOADER,
            useValue: (config) => createDotCMSURL(config, path)
        }
    ];
}
/**
 * Creates a DotCMS-compatible URL for image loading
 *
 * @param config - The image loader configuration
 * @param path - The base URL path to the DotCMS instance
 * @returns A fully qualified URL for the image
 * @internal
 */
function createDotCMSURL(config, path) {
    const { loaderParams, src, width } = config;
    const params = loaderParams;
    if (params?.isOutsideSRC) {
        return src;
    }
    // Use empty string as fallback to support using current site
    const dotcmsHost = path ? new URL(path).origin : '';
    const imageSRC = src.includes('/dA/') ? src : `/dA/${src}`;
    const languageId = params?.languageId ?? '1';
    if (width) {
        return `${dotcmsHost}${imageSRC}/${width}w?language_id=${languageId}`;
    }
    return `${dotcmsHost}${imageSRC}?language_id=${languageId}`;
}

const DEFAULT_TINYMCE_CONFIG = {
    menubar: false,
    inline: true,
    valid_styles: {
        '*': 'font-size,font-family,color,text-decoration,text-align'
    },
    powerpaste_word_import: 'clean',
    powerpaste_html_import: 'clean',
    suffix: '.min', // Suffix to use when loading resources
    license_key: 'gpl'
};
const TINYMCE_CONFIG = {
    minimal: {
        ...DEFAULT_TINYMCE_CONFIG,
        plugins: 'link autolink',
        toolbar: 'bold italic underline | link',
        valid_elements: 'strong,em,span[style],a[href]'
    },
    full: {
        ...DEFAULT_TINYMCE_CONFIG,
        plugins: 'link lists autolink charmap',
        style_formats: [
            { title: 'Paragraph', format: 'p' },
            { title: 'Header 1', format: 'h1' },
            { title: 'Header 2', format: 'h2' },
            { title: 'Header 3', format: 'h3' },
            { title: 'Header 4', format: 'h4' },
            { title: 'Header 5', format: 'h5' },
            { title: 'Header 6', format: 'h6' },
            { title: 'Pre', format: 'pre' },
            { title: 'Code', format: 'code' }
        ],
        toolbar: [
            'styleselect undo redo | bold italic underline | forecolor backcolor | alignleft aligncenter alignright alignfull | numlist bullist outdent indent | hr charmap removeformat | link'
        ]
    },
    plain: {
        ...DEFAULT_TINYMCE_CONFIG,
        plugins: '',
        toolbar: ''
    }
};

/**
 * Dot editable text component.
 * This component is responsible to render a text field that can be edited inline.
 *
 * @export
 * @class DotCMSEditableTextComponent
 * @implements {OnInit}
 * @implements {OnChanges}
 */
class DotCMSEditableTextComponent {
    constructor() {
        /**
         * Represents the mode of the editor which can be `plain`, `minimal`, or `full`
         *
         * @type {DOT_EDITABLE_TEXT_MODE}
         * @memberof DotCMSEditableTextComponent
         */
        this.mode = 'plain';
        /**
         * Represents the format of the editor which can be `text` or `html`
         *
         * @type {DOT_EDITABLE_TEXT_FORMAT}
         * @memberof DotCMSEditableTextComponent
         */
        this.format = 'text';
        /**
         * Represents the field name of the `contentlet` that can be edited
         *
         * @memberof DotCMSEditableTextComponent
         */
        this.fieldName = '';
        /**
         * Represents the content of the `contentlet` that can be edited
         *
         * @protected
         * @memberof DotCMSEditableTextComponent
         */
        this.content = '';
        this.#sanitizer = inject(DomSanitizer);
        this.#renderer = inject(Renderer2);
        this.#elementRef = inject(ElementRef);
    }
    #sanitizer;
    #renderer;
    #elementRef;
    /**
     * The TinyMCE editor
     *
     * @readonly
     * @memberof DotCMSEditableTextComponent
     */
    get editor() {
        return this.editorComponent?.editor;
    }
    /**
     * Returns the number of pages the contentlet is on
     *
     * @readonly
     * @memberof DotCMSEditableTextComponent
     */
    get onNumberOfPages() {
        return this.contentlet['onNumberOfPages'] || 1;
    }
    /**
     * Handle copy contentlet inline editing success event
     *
     * @param {MessageEvent} { data }
     * @return {*}
     * @memberof DotCMSEditableTextComponent
     */
    onMessage({ data }) {
        const { name, payload } = data;
        if (name !== NOTIFY_CLIENT.UVE_COPY_CONTENTLET_INLINE_EDITING_SUCCESS) {
            return;
        }
        const { oldInode, inode } = payload;
        const currentInode = this.contentlet.inode;
        if (currentInode === oldInode || currentInode === inode) {
            this.editorComponent.editor.focus();
            return;
        }
    }
    ngOnInit() {
        this.isInsideEditor = isInsideEditor();
        if (!this.isInsideEditor) {
            this.innerHTMLToElement();
            return;
        }
        this.init = {
            ...TINYMCE_CONFIG[this.mode],
            base_url: `${DotCmsClient.dotcmsUrl}/ext/tinymcev7`
        };
    }
    ngOnChanges() {
        this.content = this.contentlet[this.fieldName] || '';
        if (this.editor) {
            this.editor.setContent(this.content, { format: this.format });
        }
    }
    /**
     * Handle mouse down event
     *
     * @param {EventObj<MouseEvent>} { event }
     * @return {*}
     * @memberof DotCMSEditableTextComponent
     */
    onMouseDown({ event }) {
        if (this.onNumberOfPages <= 1 || this.editorComponent.editor.hasFocus()) {
            return;
        }
        const { inode, languageId: language } = this.contentlet;
        event.stopPropagation();
        event.preventDefault();
        try {
            postMessageToEditor({
                action: CLIENT_ACTIONS.COPY_CONTENTLET_INLINE_EDITING,
                payload: {
                    dataset: {
                        inode,
                        language,
                        fieldName: this.fieldName
                    }
                }
            });
        }
        catch (error) {
            console.error('Failed to post message to editor:', error);
        }
    }
    /**
     * Handle focus out event
     *
     * @return {*}
     * @memberof DotCMSEditableTextComponent
     */
    onFocusOut() {
        const content = this.editor.getContent({ format: this.format });
        if (!this.editor.isDirty() || !this.didContentChange(content)) {
            return;
        }
        const { inode, languageId: langId } = this.contentlet;
        try {
            postMessageToEditor({
                action: CLIENT_ACTIONS.UPDATE_CONTENTLET_INLINE_EDITING,
                payload: {
                    content,
                    dataset: {
                        inode,
                        langId,
                        fieldName: this.fieldName
                    }
                }
            });
        }
        catch (error) {
            console.error('Failed to post message to editor:', error);
        }
    }
    /**
     * inner HTML to element
     *
     * @private
     * @param {string} editedContent
     * @return {*}
     * @memberof DotCMSEditableTextComponent
     */
    innerHTMLToElement() {
        const element = this.#elementRef.nativeElement;
        const safeHtml = this.#sanitizer.bypassSecurityTrustHtml(this.content);
        const content = this.#sanitizer.sanitize(SecurityContext.HTML, safeHtml) || '';
        this.#renderer.setProperty(element, 'innerHTML', content);
    }
    /**
     * Check if the content has changed
     *
     * @private
     * @param {string} editedContent
     * @return {*}
     * @memberof DotCMSEditableTextComponent
     */
    didContentChange(editedContent) {
        return this.content !== editedContent;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.3", ngImport: i0, type: DotCMSEditableTextComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.3", type: DotCMSEditableTextComponent, isStandalone: true, selector: "dotcms-editable-text", inputs: { mode: "mode", format: "format", contentlet: "contentlet", fieldName: "fieldName" }, host: { listeners: { "window:message": "onMessage($event)" } }, providers: [
            {
                provide: TINYMCE_SCRIPT_SRC,
                useFactory: () => {
                    return `${DotCmsClient.dotcmsUrl}/ext/tinymcev7/tinymce.min.js`;
                }
            }
        ], viewQueries: [{ propertyName: "editorComponent", first: true, predicate: EditorComponent, descendants: true }], usesOnChanges: true, ngImport: i0, template: "@if (isInsideEditor) {\n    <editor\n        #tinyEditor\n        [init]=\"init\"\n        [initialValue]=\"content\"\n        (onMouseDown)=\"onMouseDown($event)\"\n        (onFocusOut)=\"onFocusOut()\" />\n}\n", styles: [":host ::ng-deep .mce-content-body:not(.mce-edit-focus):hover{outline:2px solid #006ce7;border-radius:4px}\n"], dependencies: [{ kind: "component", type: EditorComponent, selector: "editor", inputs: ["cloudChannel", "apiKey", "init", "id", "initialValue", "outputFormat", "inline", "tagName", "plugins", "toolbar", "modelEvents", "allowedEvents", "ignoreEvents", "disabled"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.3", ngImport: i0, type: DotCMSEditableTextComponent, decorators: [{
            type: Component,
            args: [{ selector: 'dotcms-editable-text', standalone: true, imports: [EditorComponent], providers: [
                        {
                            provide: TINYMCE_SCRIPT_SRC,
                            useFactory: () => {
                                return `${DotCmsClient.dotcmsUrl}/ext/tinymcev7/tinymce.min.js`;
                            }
                        }
                    ], template: "@if (isInsideEditor) {\n    <editor\n        #tinyEditor\n        [init]=\"init\"\n        [initialValue]=\"content\"\n        (onMouseDown)=\"onMouseDown($event)\"\n        (onFocusOut)=\"onFocusOut()\" />\n}\n", styles: [":host ::ng-deep .mce-content-body:not(.mce-edit-focus):hover{outline:2px solid #006ce7;border-radius:4px}\n"] }]
        }], propDecorators: { editorComponent: [{
                type: ViewChild,
                args: [EditorComponent]
            }], mode: [{
                type: Input
            }], format: [{
                type: Input
            }], contentlet: [{
                type: Input
            }], fieldName: [{
                type: Input
            }], onMessage: [{
                type: HostListener,
                args: ['window:message', ['$event']]
            }] } });

/**
 * Generated bundle index. Do not edit.
 */

export { DotCMSEditableTextComponent, DotCMSShowWhenDirective, provideDotCMSImageLoader };
//# sourceMappingURL=dotcms-angular-next.mjs.map
